| ebola | R Documentation |
The daily number of cases of ebola in Sierra Leone during the 2015 epidemic.
ebola
A data frame with 103 rows and 4 variables:
date
day
cumulative incidence
incidence calculated by differencing the cumcases and setting negatives to zero.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.