| tsirSim | R Documentation |
Function to simulate the stochastic TSIR assuming stochasticity in transmission and a Poisson birth-death process
tsirSim(
alpha = 0.97,
B = 2300,
beta = 25,
sdbeta = 0,
S0 = 0.06,
I0 = 180,
IT = 520,
N = 3300000
)
alpha |
the exponent on I |
B |
the birth rate |
beta |
the transmission rate |
sdbeta |
the standard deviation on beta |
S0 |
the initial susceptible fraction |
I0 |
the initial number of infected |
IT |
the length of simulation |
N |
the population size |
A list with time series of simulated infected and susceptible hosts
out = tsirSim()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.